# Flutter Document Scanner

![pub_version]
![coverage][coverage_badge]
[![style: very good analysis][very_good_analysis_badge]][very_good_analysis_link]
[![License: MIT][license_badge]][license_link]

Generated by the [Very Good CLI][very_good_cli_link] 🤖

---

🚧 Under Development! 🚧

A Flutter plugin that allows the management of taking, cropping and applying filters to an image, using
the [Camera][camera_link] plugin.

For Android use [OpenCV][opencv_link].

For iOS use [Vision Kit][vision_kit_link].


<br />

## Basic  
![demo]


## With Customizations
![demo_customizations]


---

## TODO

| Feature                           | Android | iOS |
|-----------------------------------|:-------:|:---:|
| Adjust perspective                |    ✅    | ✅ |
| Apply filters                     |    ✅    | ✅ |
| Find contours from external image |    ✅    | ✅ |
| Improve error control             |    ❌    | ❌ |
| Add Unit Test                     |    ❌    | ❌ |
| Find contours in real time        |    ❌    | ❌ |
| Taking multiple photos at once    |    ❌    | ❌ |

## Usage

First, add flutter_document_scanner as
a [dependency in your pubspec.yaml file](https://flutter.dev/docs/development/packages-and-plugins/using-packages).

Later add [camera permissions](https://pub.dev/packages/camera#installation) in the AndroidManifest.xml and Info.plist files. 


## Example

### Import libraries.

```dart
import 'package:flutter_document_scanner/flutter_document_scanner.dart';
```

### Initialize the DocumentScannerController

```dart
final _controller = DocumentScannerController();
```

### Display widget

```dart
DocumentScanner(
  controller: _controller,
  onSave: (Uint8List imageBytes) {
    print("image bytes: $imageBytes");
  },
);
```

---

## Controller Document uses

### Actions

```dart
_controller.takePhoto(minContourArea: 80000.0,);

_controller.cropPhoto();

_controller.applyFilter(FilterType.gray);

_controller.savePhotoDocument();

_controller.changePage(AppPages.cropPhoto);
```

### Can listen to the changes

```dart
_controller.statusTakePhotoPage.listen((AppStatus event) {
    print("Changes when taking the picture");
    print("[initial, loading, success, failure]");
});


_controller.statusCropPhoto.listen((AppStatus event) {
    print("Changes while cutting the image and adding warp perspective");
    print("[initial, loading, success, failure]");
});


_controller.statusEditPhoto.listen((AppStatus event) {
    print("Changes when editing the image (applying filters)");
    print("[initial, loading, success, failure]");
});


_controller.currentFilterType.listen((FilterType event) {
    print("Listen to the current filter applied on the image");
    print("[ natural, gray, eco]");
});


_controller.statusSavePhotoDocument.listen((AppStatus event) {
  print("Changes while the document image is being saved");
  print("[initial, loading, success, failure]");
});

_controller.currentPage.listen((AppPages page) {
  print("Changes in the current page");
  print("[takePhoto, cropPhoto, editDocument]");
});

```

### Can get photos
    
```dart
final File? photoTaken = _controller.pictureTaken;

final Uint8List? photoCropped = _controller.pictureCropped;
```

### Can find contours from gallery o external image
To learn more, you can see the example from_gallery_page.dart

```dart
final picker = ImagePicker();
final image = await picker.pickImage(source: ImageSource.gallery);

if (image == null) return;

await _controller.findContoursFromExternalImage(
  image: File(image.path),
);
```


---

## Customizations

### Change messages dialogs

Only if "hideDefaultDialogs" of [GeneralStyles](https://github.com/criistian14/flutter_document_scanner/blob/master/flutter_document_scanner/lib/src/utils/general_styles.dart) is set to false.

If you want to add another type of dialogs you must do it manually with the status changes and set "hideDefaultDialogs" of [GeneralStyles](https://github.com/criistian14/flutter_document_scanner/blob/master/flutter_document_scanner/lib/src/utils/general_styles.dart) to true.


```dart
DocumentScanner(
  controller: _controller,
  onSave: (Uint8List imageBytes) {
    print("image bytes: $imageBytes");
  },
  generalStyles: const GeneralStyles(
    messageTakingPicture: 'Capturando documento',
    messageCroppingPicture: 'Recortando documento',
    messageEditingPicture: 'Editando documento',
    messageSavingPicture: 'Guardando documento',
  ),
);
```

### Camera

```dart
DocumentScanner(
  controller: _controller,
  onSave: (Uint8List imageBytes) {
    print("image bytes: $imageBytes");
  },
  resolutionCamera: ResolutionPreset.high,
  initialCameraLensDirection: CameraLensDirection.front,
);
```

### Page transitions

```dart
DocumentScanner(
  controller: _controller,
  onSave: (Uint8List imageBytes) {
    print("image bytes: $imageBytes");
  },
  pageTransitionBuilder: (child, animation) {
    final tween = Tween(begin: 0.0, end: 1.0);

    final curvedAnimation = CurvedAnimation(
      parent: animation,
      curve: Curves.easeOutCubic,
    );

    return FadeTransition(
      opacity: tween.animate(curvedAnimation),
      child: child,
    );
  },
);

```

### General Styles

The properties are
listed [here](https://github.com/criistian14/flutter_document_scanner/blob/master/flutter_document_scanner/lib/src/utils/general_styles.dart)

---

## Page Styles

If you want to add widgets or modify elements of each page you can do it with their respective style per page.

### Page to take the photo

The properties are
listed [here](https://github.com/criistian14/flutter_document_scanner/blob/master/flutter_document_scanner/lib/src/utils/take_photo_document_style.dart)

### Page to crop the image

The properties are
listed [here](https://github.com/criistian14/flutter_document_scanner/blob/master/flutter_document_scanner/lib/src/utils/crop_photo_document_style.dart)

### Page to edit image

The properties are
listed [here](https://github.com/criistian14/flutter_document_scanner/blob/master/flutter_document_scanner/lib/src/utils/edit_photo_document_style.dart)


[pub_version]: https://img.shields.io/pub/v/flutter_document_scanner.svg

[workflow_badge]: https://github.com/criistian14/flutter_document_scanner/actions/workflows/main.yml/badge.svg

[demo]: https://media.giphy.com/media/flQWXeHif35IsSQOOO/giphy.gif

[demo_customizations]: https://media.giphy.com/media/rS6qYbtuuRbo8Fra3d/giphy.gif

[coverage_badge]: https://codecov.io/gh/criistian14/flutter_document_scanner/branch/master/graph/badge.svg?token=2U7891NVMO

[license_badge]: https://img.shields.io/badge/license-MIT-blue.svg

[license_link]: https://opensource.org/licenses/MIT

[very_good_analysis_badge]: https://img.shields.io/badge/style-very_good_analysis-B22C89.svg

[very_good_analysis_link]: https://pub.dev/packages/very_good_analysis

[very_good_cli_link]: https://github.com/VeryGoodOpenSource/very_good_cli

[camera_link]: https://pub.dev/packages/camera

[opencv_link]: https://opencv.org/

[vision_kit_link]: https://developer.apple.com/documentation/visionkit
